//----------------------------------------------------------------------------
//  Project AlphaBlending
//
//  Copyright  1997. All Rights Reserved.
//
//  SUBSYSTEM:    AlphaBlending Application
//  FILE:         alphablendingdlgclient.cpp
//  AUTHOR:
//
//  OVERVIEW
//  ~~~~~~~~
//  Source file for implementation of TAlphaBlendingDlgClient (TDialog).
//
//----------------------------------------------------------------------------

#include <owl/pch.h>

#include "alphablendingapp.h"
#include "alphablendingdlgclient.h"


//
// Build a response table for all messages/commands handled by the application.
//
DEFINE_RESPONSE_TABLE1(TAlphaBlendingDlgClient, TDialog)
//{{TAlphaBlendingDlgClientRSP_TBL_BEGIN}}
  EV_WM_TIMER,
  EV_WM_ACTIVATE,
//{{TAlphaBlendingDlgClientRSP_TBL_END}}
END_RESPONSE_TABLE;


//{{TAlphaBlendingDlgClient Implementation}}

#if !defined WS_EX_LAYERED
#define WS_EX_LAYERED           0x00080000
#define LWA_ALPHA               0x00000002
#endif

typedef HWND WINAPI (*SetLayeredWinFunc)( HWND hwnd, COLORREF crKey, BYTE bAlpha, DWORD dwFlags);

HMODULE hUser32=NULL;
SetLayeredWinFunc mySetLayeredWindow=NULL;


//--------------------------------------------------------
// TAlphaBlendingDlgClient
// ~~~~~~~~~~
// Construction/Destruction handling.
//
TAlphaBlendingDlgClient::TAlphaBlendingDlgClient(TWindow* parent, TResId resId, TModule* module)
:
  TDialog(parent, resId, module)
{
  // INSERT>> Your constructor code here.

   hUser32=LoadLibrary("USER32.DLL"); 
   if (hUser32) {
		mySetLayeredWindow = (SetLayeredWinFunc)GetProcAddress(hUser32, "SetLayeredWindowAttributes");
   }
	alphaValue=255;
   alphaLimit=64;
	SetBkgndColor(RGB(0x80, 0xA0, 0xe0)); //8f af cf
}


TAlphaBlendingDlgClient::~TAlphaBlendingDlgClient(){
	if (hUser32)
   	FreeLibrary(hUser32);

  Destroy();

  // INSERT>> Your destructor code here.
}

void TAlphaBlendingDlgClient::SetupWindow() {
	TDialog::SetupWindow();

	// INSERT>> Your code here.
	if (mySetLayeredWindow) {
		Parent->SetWindowLong(GWL_EXSTYLE, Parent->GetWindowLong(GWL_EXSTYLE)|WS_EX_LAYERED);
      mySetLayeredWindow(Parent->HWindow,RGB(0,0,0), alphaValue, LWA_ALPHA);
	}

}


void TAlphaBlendingDlgClient::EvTimer(uint timerId){
    TDialog::EvTimer(timerId);

  // INSERT>> Your code here.
	if (alphaValue>alphaLimit) {
  		--alphaValue;
		if (mySetLayeredWindow)
	      mySetLayeredWindow(Parent->HWindow,RGB(0,0,0), alphaValue, LWA_ALPHA);
	}
   else
   	KillTimer(100);

}


void TAlphaBlendingDlgClient::EvActivate(uint active, bool minimized, THandle hWndOther )
{
    TDialog::EvActivate(active, minimized, hWndOther );

  // INSERT>> Your code here.
	if (active) {
   	alphaValue=255;
   	if (mySetLayeredWindow)
	      mySetLayeredWindow(Parent->HWindow,RGB(0,0,0), alphaValue, LWA_ALPHA);
   	KillTimer(50);
   }
   else {
   	SetTimer( 50, 50);
   }

}

